Group: Graphical desktop/Other
# BEGIN SourceDeps(oneline):
BuildRequires(pre): rpm-macros-fedora-compat
BuildRequires: /usr/bin/desktop-file-install
# END SourceDeps(oneline)
# see https://bugzilla.altlinux.org/show_bug.cgi?id=10382
%define _localstatedir %{_var}
%global         main_ver      1.4.5
%global         vendor_rel    4

%global         reponame      ClipIt
%global         gitdate       20210513
%global         gitcommit     e5fa64c216c1b02a43cb3c90e8a151e43e881d96
%global         shortcommit   %(c=%{gitcommit}; echo ${c:0:7})

%global         tarballdate   20210922
%global         tarballtime   1754

%global         use_release   0
%global         use_gitbare  1
%global         use_gitcommit_as_rel  1

%if 0%{?use_gitbare} < 1
%global         use_release   1
%endif

%if 0%{?use_gitcommit_as_rel} >= 1
%global         rel           %{vendor_rel}.D%{gitdate}git%{shortcommit}%{?dist}
%else
%define         rel           %{vendor_rel}%{?dist}
%endif


Name:           clipit
Version:        %{main_ver}
Release:        alt1_%{rel}.5
Summary:        A lightweight, fully featured GTK+ clipboard manager

License:        GPLv3+
URL:            https://github.com/CristianHenzel/ClipIt
%if 0%{?use_release} >= 1
Source0:        https://github.com/CristianHenzel/ClipIt/archive/v%{version}.tar.gz
%else
Source0:        %{reponame}-%{tarballdate}T%{tarballtime}.tar.gz
%endif
Source1:        %{name}.appdata.xml
# clipit doesn't autostart in MATE
# Fixed upstream but not yet merged
Patch0:         0001-Autostart-in-MATE.patch
# Force GDK_BACKEND to x11
Patch1:         clipit-1.4.5-force-gdk_backend-x11.patch
Patch2:         clipit-c99.patch

%if 0%{?use_gitbare} >= 1
BuildRequires:  git
%endif
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  desktop-file-utils
BuildRequires:  intltool
BuildRequires:  gettext-tools
BuildRequires:  %{_bindir}/appstream-util
Requires:       xdotool
Source44: import.info

%description
ClipIt is a lightweight, fully featured GTK+ clipboard manager. It was forked
from Parcellite, adding additional features and bug-fixes to the project.
ClipIts main features are:
* Save a history of your last copied items
* Search through the history
* Global hot-keys for most used functions
* Execute actions with clipboard items
* Exclude specific items from history


%prep
%if 0%{?use_release} >= 1
%setup -q -n %{reponame}-%{version}
%endif

%if 0%{?use_gitbare} >= 1
%setup -q -c -T -a 0
git clone ./%{reponame}.git

cd %{reponame}
git checkout -b fedora-%{version}-head %{gitcommit}
cp -a [A-Z]* ..

git config user.name "%{name} Fedora maintainer"
git config user.email "%{name}-maintainer@fedoraproject.org"
%endif

%patch0 -p1 -b .mate
%patch1 -p1 -b .nowayland
%patch2 -p1

sed -i data/clipit.desktop.in -e '\@_Comment.*hr@d'
sed -i data/clipit-startup.desktop.in -e '\@_Comment.*hr@d'

%if 0%{?use_gitbare} >= 1
git commit -m "Apply Fedora specific configuration" -a
%endif

./autogen.sh

%build
%if 0%{?use_gitbare} >= 1
cd %{reponame}
%endif

%configure \
	--with-gtk3 \
	%{nil}
%make_build

%install
%if 0%{?use_gitbare} >= 1
cd %{reponame}
%endif

%makeinstall_std

%if 0%{?use_gitbare} >= 1
cd ..
%endif

%find_lang %{name}

desktop-file-install --delete-original \
    --remove-category=Application \
    --dir %{buildroot}%{_datadir}/applications \
    %{buildroot}%{_datadir}/applications/%{name}.desktop

desktop-file-install --delete-original \
    --dir %{buildroot}%{_sysconfdir}/xdg/autostart \
    %{buildroot}%{_sysconfdir}/xdg/autostart/%{name}-startup.desktop

mkdir -p %{buildroot}%{_metainfodir}
install -c -p -m 644 %{SOURCE1} %{buildroot}%{_metainfodir}/%{name}.appdata.xml

%check
appstream-util validate-relax --nonet %{buildroot}%{_metainfodir}/%{name}.appdata.xml

%files -f %{name}.lang
%doc --no-dereference COPYING
%doc AUTHORS
%doc ChangeLog
%doc README.md

%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*
%{_datadir}/icons/hicolor/scalable/apps/%{name}-trayicon*.svg
%{_metainfodir}/%{name}.appdata.xml

%{_datadir}/applications/%{name}.desktop
%config(noreplace) %{_sysconfdir}/xdg/autostart/%{name}-startup.desktop

%changelog
* Thu Aug 31 2023 Igor Vlasenko <viy@altlinux.org> 1.4.5-alt1_4.5
- update to new release by fcimport

* Wed Feb 22 2023 Igor Vlasenko <viy@altlinux.org> 1.4.5-alt1_4.4
- update to new release by fcimport

* Sun Aug 07 2022 Igor Vlasenko <viy@altlinux.org> 1.4.5-alt1_4.2
- update to new release by fcimport

* Sat Feb 05 2022 Igor Vlasenko <viy@altlinux.org> 1.4.5-alt1_4.1
- update to new release by fcimport

* Wed Oct 13 2021 Igor Vlasenko <viy@altlinux.org> 1.4.5-alt1_4
- update to new release by fcimport

* Mon Aug 02 2021 Igor Vlasenko <viy@altlinux.org> 1.4.5-alt1_3
- update to new release by fcimport

* Wed Apr 14 2021 Igor Vlasenko <viy@altlinux.org> 1.4.5-alt1_2
- update to new release by fcimport

* Wed Mar 17 2021 Igor Vlasenko <viy@altlinux.org> 1.4.4-alt2_9
- update to new release by fcimport

* Wed Jan 27 2021 Igor Vlasenko <viy@altlinux.ru> 1.4.4-alt2_8
- update to new release by fcimport

* Thu Oct 01 2020 Igor Vlasenko <viy@altlinux.ru> 1.4.4-alt1_8
- update to new release by fcimport

* Wed Sep 02 2020 Igor Vlasenko <viy@altlinux.ru> 1.4.4-alt1_7
- update to new release by fcimport

* Thu Mar 05 2020 Igor Vlasenko <viy@altlinux.ru> 1.4.4-alt1_6
- update to new release by fcimport

* Tue Aug 06 2019 Igor Vlasenko <viy@altlinux.ru> 1.4.4-alt1_5
- update to new release by fcimport

* Fri Mar 01 2019 Igor Vlasenko <viy@altlinux.ru> 1.4.4-alt1_4
- update to new release by fcimport

* Wed Aug 01 2018 Igor Vlasenko <viy@altlinux.ru> 1.4.4-alt1_3
- update to new release by fcimport

* Sun Jul 15 2018 Igor Vlasenko <viy@altlinux.ru> 1.4.4-alt1_2
- update to new release by fcimport

* Thu Mar 08 2018 Igor Vlasenko <viy@altlinux.ru> 1.4.2-alt1_17
- update to new release by fcimport

* Tue Feb 20 2018 Igor Vlasenko <viy@altlinux.ru> 1.4.2-alt1_16
- update to new release by fcimport

* Mon Feb 05 2018 Igor Vlasenko <viy@altlinux.ru> 1.4.2-alt1_15
- update to new release by fcimport

* Wed Sep 27 2017 Igor Vlasenko <viy@altlinux.ru> 1.4.2-alt1_14
- update to new release by fcimport

* Wed Mar 15 2017 Igor Vlasenko <viy@altlinux.ru> 1.4.2-alt1_12
- update to new release by fcimport

* Wed Mar 02 2016 Igor Vlasenko <viy@altlinux.ru> 1.4.2-alt1_11
- update to new release by fcimport

* Mon Sep 21 2015 Igor Vlasenko <viy@altlinux.ru> 1.4.2-alt1_10
- update to new release by fcimport

* Tue Dec 23 2014 Igor Vlasenko <viy@altlinux.ru> 1.4.2-alt1_9
- update to new release by fcimport

* Wed Sep 10 2014 Igor Vlasenko <viy@altlinux.ru> 1.4.2-alt1_8
- update to new release by fcimport

* Tue Jul 01 2014 Igor Vlasenko <viy@altlinux.ru> 1.4.2-alt1_7
- update to new release by fcimport

* Wed May 14 2014 Igor Vlasenko <viy@altlinux.ru> 1.4.2-alt1_6
- update to new release by fcimport

* Thu Sep 19 2013 Igor Vlasenko <viy@altlinux.ru> 1.4.2-alt1_5
- update to new release by fcimport

* Thu Aug 22 2013 Igor Vlasenko <viy@altlinux.ru> 1.4.2-alt1_4
- update to new release by fcimport

* Thu Feb 21 2013 Igor Vlasenko <viy@altlinux.ru> 1.4.2-alt1_3
- update to new release by fcimport

* Thu Aug 02 2012 Igor Vlasenko <viy@altlinux.ru> 1.4.2-alt1_2
- update to new release by fcimport

* Wed Jun 20 2012 Igor Vlasenko <viy@altlinux.ru> 1.4.2-alt1_1
- fc import

